"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[1109],{40409:(n,e,t)=>{t.r(e),t.d(e,{Signal:()=>l});var i,c=t(39233);class l{constructor(n){this.sender=n}connect(n,e){return i.connect(this,n,e)}disconnect(n,e){return i.disconnect(this,n,e)}emit(n){i.emit(this,n)}}!function(n){n.disconnectBetween=function(n,e){i.disconnectBetween(n,e)},n.disconnectSender=function(n){i.disconnectSender(n)},n.disconnectReceiver=function(n){i.disconnectReceiver(n)},n.disconnectAll=function(n){i.disconnectAll(n)},n.clearData=function(n){i.disconnectAll(n)},n.getExceptionHandler=function(){return i.exceptionHandler},n.setExceptionHandler=function(n){let e=i.exceptionHandler;return i.exceptionHandler=n,e}}(l||(l={})),function(n){function e(n){let e=i.get(n);if(e&&0!==e.length){for(const n of e){if(!n.signal)continue;let e=n.thisArg||n.slot;n.signal=null,f(l.get(e))}f(e)}}function t(n){let e=l.get(n);if(e&&0!==e.length){for(const n of e){if(!n.signal)continue;let e=n.signal.sender;n.signal=null,f(i.get(e))}f(e)}}n.exceptionHandler=n=>{console.error(n)},n.connect=function(n,e,t){t=t||void 0;let c=i.get(n.sender);if(c||(c=[],i.set(n.sender,c)),s(c,n,e,t))return!1;let o=t||e,r=l.get(o);r||(r=[],l.set(o,r));let u={signal:n,slot:e,thisArg:t};return c.push(u),r.push(u),!0},n.disconnect=function(n,e,t){t=t||void 0;let c=i.get(n.sender);if(!c||0===c.length)return!1;let o=s(c,n,e,t);if(!o)return!1;let r=t||e,u=l.get(r);return o.signal=null,f(c),f(u),!0},n.disconnectBetween=function(n,e){let t=i.get(n);if(!t||0===t.length)return;let c=l.get(e);if(c&&0!==c.length){for(const e of c)e.signal&&e.signal.sender===n&&(e.signal=null);f(t),f(c)}},n.disconnectSender=e,n.disconnectReceiver=t,n.disconnectAll=function(n){e(n),t(n)},n.emit=function(n,e){let t=i.get(n.sender);if(t&&0!==t.length)for(let i=0,c=t.length;i<c;++i){let c=t[i];c.signal===n&&u(c,e)}};const i=new WeakMap,l=new WeakMap,o=new Set,r="function"==typeof requestAnimationFrame?requestAnimationFrame:setImmediate;function s(n,e,t,i){return(0,c.find)(n,(n=>n.signal===e&&n.slot===t&&n.thisArg===i))}function u(e,t){let{signal:i,slot:c,thisArg:l}=e;try{c.call(l,i.sender,t)}catch(e){n.exceptionHandler(e)}}function f(n){0===o.size&&r(a),o.add(n)}function a(){o.forEach(d),o.clear()}function d(n){c.ArrayExt.removeAllWhere(n,g)}function g(n){return null===n.signal}}(i||(i={}))}}]);