"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[1650,8875],{71650:(e,t,o)=>{o.r(t),o.d(t,{default:()=>a});var n=o(46605);const a=[{id:"@jupyter-notebook/docmanager-extension:opener",requires:[o(79075).IDocumentManager],autoStart:!0,activate:(e,t)=>{const o=n.PageConfig.getBaseUrl(),a=t.open;t.open=(e,r="default",u,l)=>{if("_noref"===(null==l?void 0:l.ref))return void a.call(t,e,r,u,l);const i=n.PathExt.extname(e);let s="edit";("default"===r&&".ipynb"===i||"Notebook"===r)&&(s="notebooks");let c=`${o}${s}/${e}`;"default"!==r&&(c=`${c}?factory=${r}`),window.open(c)}}}]}}]);