"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5060,9434],{79434:(e,r,t)=>{t.r(r),t.d(r,{default:()=>u});var o=t(46605),n=t(90608),i=t(60460),s=t(15821);const u=[{id:"@jupyterlab/docprovider-extension:plugin",requires:[i.ICurrentUser],provides:n.IDocumentProviderFactory,activate:(e,r)=>{const t=s.ServerConnection.makeSettings(),i=o.URLExt.join(t.wsUrl,"api/yjs"),u="true"==o.PageConfig.getOption("collaborative");return e=>u?new n.WebSocketProvider({...e,url:i,user:r}):new n.ProviderMock}}]}}]);