(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[4397,2040],{22592:(t,e,n)=>{"use strict";n.d(e,{JG:()=>o,UI:()=>u,Ue:()=>r,Yj:()=>c,Yu:()=>i});const r=()=>new Map,o=t=>{const e=r();return t.forEach(((t,n)=>{e.set(n,t)})),e},i=(t,e,n)=>{let r=t.get(e);return void 0===r&&t.set(e,r=n()),r},u=(t,e)=>{const n=[];for(const[r,o]of t)n.push(e(o,r));return n},c=(t,e)=>{for(const[n,r]of t)if(e(r,n))return!0;return!1}},11182:(t,e,n)=>{"use strict";n.d(e,{Fp:()=>u,GR:()=>s,GW:()=>r,VV:()=>i,Wn:()=>o,sQ:()=>c});const r=Math.floor,o=(Math.ceil,Math.abs),i=(Math.imul,Math.round,Math.log10,Math.log2,Math.log,Math.sqrt,(t,e)=>t<e?t:e),u=(t,e)=>t>e?t:e,c=(Number.isNaN,Math.pow),s=(Math.sign,t=>0!==t?t<0:1/t<0)},27061:t=>{var e,n,r=t.exports={};function o(){throw new Error("setTimeout has not been defined")}function i(){throw new Error("clearTimeout has not been defined")}function u(t){if(e===setTimeout)return setTimeout(t,0);if((e===o||!e)&&setTimeout)return e=setTimeout,setTimeout(t,0);try{return e(t,0)}catch(n){try{return e.call(null,t,0)}catch(n){return e.call(this,t,0)}}}!function(){try{e="function"==typeof setTimeout?setTimeout:o}catch(t){e=o}try{n="function"==typeof clearTimeout?clearTimeout:i}catch(t){n=i}}();var c,s=[],a=!1,l=-1;function h(){a&&c&&(a=!1,c.length?s=c.concat(s):l=-1,s.length&&f())}function f(){if(!a){var t=u(h);a=!0;for(var e=s.length;e;){for(c=s,s=[];++l<e;)c&&c[l].run();l=-1,e=s.length}c=null,a=!1,function(t){if(n===clearTimeout)return clearTimeout(t);if((n===i||!n)&&clearTimeout)return n=clearTimeout,clearTimeout(t);try{n(t)}catch(e){try{return n.call(null,t)}catch(e){return n.call(this,t)}}}(t)}}function p(t,e){this.fun=t,this.array=e}function T(){}r.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)e[n-1]=arguments[n];s.push(new p(t,e)),1!==s.length||a||u(f)},p.prototype.run=function(){this.fun.apply(null,this.array)},r.title="browser",r.browser=!0,r.env={},r.argv=[],r.version="",r.versions={},r.on=T,r.addListener=T,r.once=T,r.off=T,r.removeListener=T,r.removeAllListeners=T,r.emit=T,r.prependListener=T,r.prependOnceListener=T,r.listeners=function(t){return[]},r.binding=function(t){throw new Error("process.binding is not supported")},r.cwd=function(){return"/"},r.chdir=function(t){throw new Error("process.chdir is not supported")},r.umask=function(){return 0}}}]);