"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6720],{66720:(e,o,t)=>{t.r(o),t.d(o,{default:()=>g});var r=t(46693),n=t(87191),a=t(4857),i=t(67846),s=t(86072),l=t(75291),d=t(34340),c=t(86604);const b="FileBrowser",u={id:"@jupyter-notebook/tree-extension:new",requires:[s.ITranslator],optional:[r.IToolbarWidgetRegistry],autoStart:!0,activate:(e,o,t)=>{const{commands:r}=e,n=o.load("notebook"),a=new d.MenuBar,i=new d.Menu({commands:r});i.title.label=n.__("New"),i.title.icon=l.caretDownIcon,a.addMenu(i),["notebook:create-new","terminal:create-new","console:create","filebrowser:create-new-file","filebrowser:create-new-directory"].forEach((e=>{i.addItem({command:e})})),t&&t.addFactory(b,"new-dropdown",(e=>{const o=new d.MenuBar;return o.addMenu(i),o.addClass("jp-DropdownMenu"),o}))}},w={id:"@jupyter-notebook/tree-extension:widget",requires:[n.IFileBrowserFactory,s.ITranslator,a.ISettingRegistry,r.IToolbarWidgetRegistry],optional:[i.IRunningSessionManagers],autoStart:!0,provides:c.INotebookTree,activate:(e,o,t,a,s,d)=>{const u=new c.NotebookTreeWidget,g=t.load("notebook"),{defaultBrowser:p}=o;if(p.title.label=g.__("Files"),p.node.setAttribute("role","region"),p.node.setAttribute("aria-label",g.__("File Browser Section")),p.title.icon=l.folderIcon,u.addWidget(p),u.tabBar.addTab(p.title),s.addFactory(b,"uploader",(e=>new n.Uploader({model:e.model,translator:t,label:g.__("Upload")}))),(0,r.setToolbar)(p,(0,r.createToolbarFactory)(s,a,b,w.id,t)),d){const e=new i.RunningSessions(d,t);e.id="jp-running-sessions",e.title.label=g.__("Running"),e.title.icon=l.runningIcon,u.addWidget(e),u.tabBar.addTab(e.title)}const T=a.load("@jupyterlab/filebrowser-extension:browser");return Promise.all([T,e.restored]).then((([e])=>{void 0===e.user.showFileCheckboxes&&e.set("showFileCheckboxes",!0)})).catch((e=>{console.error(e.message)})),e.shell.add(u,"main",{rank:100}),u}},g=[u,w]}}]);