"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[9380],{19380:(e,t,o)=>{o.r(t),o.d(t,{default:()=>m});var a=o(46693),n=o(89845),l=o(86072),r=o(7686),u=o(72245);const s=[{text:"About Jupyter",url:"https://jupyter.org"},{text:"Markdown Reference",url:"https://commonmark.org/help/"}];var c;!function(e){e.open="help:open",e.shortcuts="help:shortcuts",e.about="help:about"}(c||(c={}));const m={id:"@jupyter-notebook/help-extension:plugin",autoStart:!0,requires:[l.ITranslator],optional:[n.IMainMenu],activate:(e,t,o)=>{const{commands:n}=e,l=t.load("notebook");n.addCommand(c.open,{label:e=>e.text,execute:e=>{const t=e.url;window.open(t)}}),n.addCommand(c.shortcuts,{label:l.__("Keyboard Shortcuts"),execute:()=>{const e=u.createElement("span",{className:"jp-AboutNotebook-about-header"},u.createElement("div",{className:"jp-AboutNotebook-about-header-info"},l.__("Keyboard Shortcuts"))),t=u.createElement("table",{className:"jp-AboutNotebook-shortcuts"},u.createElement("thead",null,u.createElement("tr",null,u.createElement("th",null,l.__("Name")),u.createElement("th",null,l.__("Shortcut")))),u.createElement("tbody",null,n.keyBindings.filter((e=>n.isEnabled(e.command))).map(((e,t)=>u.createElement("tr",{key:t},u.createElement("td",null,n.label(e.command)),u.createElement("td",null,u.createElement("pre",null,e.keys.join(", "))))))));return(0,a.showDialog)({title:e,body:t,buttons:[a.Dialog.createButton({label:l.__("Dismiss"),className:"jp-AboutNotebook-about-button jp-mod-reject jp-mod-styled"})]})}}),n.addCommand(c.about,{label:l.__("About %1",e.name),execute:()=>{const t=u.createElement(u.Fragment,null,u.createElement("span",{className:"jp-AboutNotebook-header"},u.createElement(r.jupyterIcon.react,{width:"196px",height:"auto"}))),o=l.__("JUPYTER NOTEBOOK ON GITHUB"),n=u.createElement("span",null,u.createElement("a",{href:"https://github.com/jupyter/notebook",target:"_blank",rel:"noopener noreferrer",className:"jp-Button-flat jp-AboutNotebook-about-externalLinks"},o)),s=l.__("Version: %1",e.version),c=u.createElement(u.Fragment,null,u.createElement("span",{className:"jp-AboutNotebook-body"},s),u.createElement("div",null,n)),m=new a.Dialog({title:t,body:c,buttons:[a.Dialog.createButton({label:l.__("Dismiss"),className:"jp-AboutNotebook-about-button jp-mod-reject jp-mod-styled"})]});m.addClass("jp-AboutNotebook"),m.launch()}});const m=s.map((e=>({args:e,command:c.open})));o&&o.helpMenu.addGroup(m,30)}}}}]);